Setup and site configuration
============================

This section describes how to setup `pglift` on target host and explains
various aspects of deployment operations.

.. toctree::

    settings
    postgresql_configuration
    postgresql_authentication
    systemd
